==> vux-loader-2.1.0.tgz: package/plugins/duplicate-style/index.js <==
/**
* https://github.com/NMFR/optimize-css-assets-webpack-plugin
* MIT LICENSE
*/

let _ = require('underscore')
let webpackSources = require('webpack-sources')

function OptimizeCssAssetsPlugin(options) {
  options = options || {}
  this.options = Object.assign({
    canPrint: undefined,
    cssProcessor: require('cssnano'),
    assetNameRegExp : /\.css$/g,
    cssProcessorOptions : {
      safe: true,
      zindex: false,
      autoprefixer: false
    }
  }, options)
};

OptimizeCssAssetsPlugin.prototype.print = function() {
  if (this.options.canPrint || (typeof this.options.canPrint === 'undefined' && (process.env.NODE_ENV === 'production' || process.env.__VUX_BUILD__))) {
    console.log.apply(console, arguments);
  }
};

OptimizeCssAssetsPlugin.prototype.processCss = function(css) {
  return this.options.cssProcessor.process(css, this.options.cssProcessorOptions)
};

OptimizeCssAssetsPlugin.prototype.createCssAsset = function(css, originalAsset) {
  return new webpackSources.RawSource(css);
};

OptimizeCssAssetsPlugin.prototype.apply = function(compiler) {
  let self = this;
  compiler.hooks.emit.tap('@vux/loader', function(compilation, compileCallback) {
    self.print('\n\n======== vux-loader: duplicate-style start~  ========')
    self.print('Starting to optimize CSS...')

    let assets = compilation.assets;

    let cssAssetNames = _.filter(
      _.keys(assets),
      function(assetName) {
        return assetName.match(self.options.assetNameRegExp)
      }
    );

    let hasErrors = false;
    let promises = [];

    _.each(
      cssAssetNames,
      function(assetName) {
        self.print('Processing ' + assetName + '...')
        let asset = assets[assetName];
        let originalCss = asset.source();
        // avoid 0% => 0
        originalCss = originalCss.replace(/:\s*0%/g, ':1234%')
        let promise = self.processCss(originalCss)
        promise.then(
          function (result) {
            if (hasErrors) {
              self.print('Skiping ' + assetName + ' because of an error.')
              return;
            }
            let processedCss = result.css;
            // replace back to 0%
            processedCss = processedCss.replace(/:1234%/g, ':0%')
            assets[assetName] = self.createCssAsset(processedCss, asset);
            let ratio = ''
            if (originalCss.length) {
              ratio = ', ratio:' + (Math.round(((processedCss.length * 100) / originalCss.length) * 100) / 100) + '%'
            }
            self.print('Processed ' + assetName + ', before: ' + originalCss.length + ', after: ' + processedCss.length + ratio)
          }, function(err) {
            hasErrors = true;
            self.print('Error processing file: ' + assetName)
            console.error(err)
          }
        );
        promises.push(promise)
      }
    );

    Promise.all(promises).then(function () {
      compileCallback()
      self.print('======== vux-loader: duplicate-style done!   ========\n')
     }, compileCallback)
  })
}

module.exports = OptimizeCssAssetsPlugin

==> vux-loader-2.2.0.tgz: package/plugins/duplicate-style/index.js <==
/**
* https://github.com/NMFR/optimize-css-assets-webpack-plugin
* MIT LICENSE
*/

let _ = require('underscore')
let webpackSources = require('webpack-sources')

function OptimizeCssAssetsPlugin(options) {
  options = options || {}
  this.options = Object.assign({
    canPrint: undefined,
    cssProcessor: require('cssnano'),
    assetNameRegExp : /\.css$/g,
    cssProcessorOptions : {
      safe: true,
      zindex: false,
      autoprefixer: false
    }
  }, options)
};

OptimizeCssAssetsPlugin.prototype.print = function() {
  if (this.options.canPrint || (typeof this.options.canPrint === 'undefined' && (process.env.NODE_ENV === 'production' || process.env.__VUX_BUILD__))) {
    console.log.apply(console, arguments);
  }
};

OptimizeCssAssetsPlugin.prototype.processCss = function(css) {
  return this.options.cssProcessor.process(css, this.options.cssProcessorOptions)
};

OptimizeCssAssetsPlugin.prototype.createCssAsset = function(css, originalAsset) {
  return new webpackSources.RawSource(css);
};

OptimizeCssAssetsPlugin.prototype.apply = function(compiler) {
  let self = this;
  compiler.hooks.emit.tapAsync('@vux/loader', function(compilation, compileCallback) {
    self.print('\n\n======== vux-loader: duplicate-style start~  ========')
    self.print('Starting to optimize CSS...')

    let assets = compilation.assets;

    let cssAssetNames = _.filter(
      _.keys(assets),
      function(assetName) {
        return assetName.match(self.options.assetNameRegExp)
      }
    );

    let hasErrors = false;
    let promises = [];

    _.each(
      cssAssetNames,
      function(assetName) {
        self.print('Processing ' + assetName + '...')
        let asset = assets[assetName];
        let originalCss = asset.source();
        // avoid 0% => 0
        originalCss = originalCss.replace(/:\s*0%/g, ':1234%')
        let promise = self.processCss(originalCss)
        promise.then(
          function (result) {
            if (hasErrors) {
              self.print('Skiping ' + assetName + ' because of an error.')
              return;
            }
            let processedCss = result.css;
            // replace back to 0%
            processedCss = processedCss.replace(/:1234%/g, ':0%')
            assets[assetName] = self.createCssAsset(processedCss, asset);
            let ratio = ''
            if (originalCss.length) {
              ratio = ', ratio:' + (Math.round(((processedCss.length * 100) / originalCss.length) * 100) / 100) + '%'
            }
            self.print('Processed ' + assetName + ', before: ' + originalCss.length + ', after: ' + processedCss.length + ratio)
          }, function(err) {
            hasErrors = true;
            self.print('Error processing file: ' + assetName)
            console.error(err)
          }
        );
        promises.push(promise)
      }
    );

    Promise.all(promises).then(function () {
      compileCallback()
      self.print('======== vux-loader: duplicate-style done!   ========\n')
     }, compileCallback)
  })
}

module.exports = OptimizeCssAssetsPlugin
